==> dealii-9.5.0-offline_documentation.tar.gz: doc/doxygen/deal.II/search/enumvalues_6.js <==
var searchData=
[
  ['gauss_5fjordan_0',['gauss_jordan',['../classPreconditionBlockBase.html#a0eb89cc35edc5ec8ef14baed1bbe9c66a57018c50701d00bdd089ed6c504f7cec',1,'PreconditionBlockBase']]],
  ['gaussianelimination_1',['GaussianElimination',['../structPETScWrappers_1_1PreconditionBoomerAMG_1_1AdditionalData.html#a5d92688a1fdd10088cddaf971b84e987ad29a355c6863a9d059169ef1fe131dcb',1,'PETScWrappers::PreconditionBoomerAMG::AdditionalData']]],
  ['general_2',['general',['../group__matrixfree.html#ggae024b29b6819e727d47016c6b6b53d8caec90e87a9874dab5ed93ed8793c58278',1,'internal::MatrixFreeFunctions::general'],['../namespaceLAPACKSupport.html#a45557450a3c1ae0e74d7ddf12c43bc98af25b68380698c53fa6da3e05379c0855',1,'LAPACKSupport::general']]],
  ['ghosted_3',['ghosted',['../structinternal_1_1MatrixFreeFunctions_1_1FaceSetup.html#aa8e29ddb5aafdd94db26be53c217f2eea4f7b10490f32a913036c1a09e14cc65e',1,'internal::MatrixFreeFunctions::FaceSetup']]],
  ['gmres_4',['gmres',['../classTrilinosWrappers_1_1SolverBase.html#afdefddba07cdfc566bfb749bcb5b0840aeb4057f8f19a15c916b61eaba68d5835',1,'TrilinosWrappers::SolverBase']]],
  ['gmv_5',['gmv',['../namespaceDataOutBase.html#aa3cbced9f1d4ae661f13018f4c980aa1a958eea3b2724c76d1c1ff20d69f7da4e',1,'DataOutBase']]],
  ['gnuplot_6',['gnuplot',['../classGridOut.html#af24aadcd00f93b7f428f44ecd40c44d9a9becaeaa34ee67f9686fef40075176e6',1,'GridOut::gnuplot'],['../namespaceDataOutBase.html#aa3cbced9f1d4ae661f13018f4c980aa1a025233c1a8124e5521952c7c7cd78df1',1,'DataOutBase::gnuplot']]],
  ['go_5fto_5fone_7',['go_to_one',['../namespaceMGTransferGlobalCoarseningTools.html#a0b3ae7f7ace3aef7bdcbca73ae07c126a4700af23eb58d665b1bffa9b2d8bd01a',1,'MGTransferGlobalCoarseningTools']]],
  ['gradient_8',['gradient',['../namespaceinternal.html#aa5bef221c94bc6b9c5441c306a72cdbaae2b6dfb8a5c48206992d8310d176c37c',1,'internal']]],
  ['gradients_9',['gradients',['../classMatrixFree.html#a751b5f06534d52773eba384d2c866a15ac2af294b46c59f4ca21a4aac2b2d97b1',1,'MatrixFree::gradients'],['../namespaceEvaluationFlags.html#a9b7c6d689cb76386839d0d13640f59aea91b5f00e4be473005cc331b8644ab2f1',1,'EvaluationFlags::gradients']]],
  ['gradients_5fall_5ffaces_10',['gradients_all_faces',['../classMatrixFree.html#a751b5f06534d52773eba384d2c866a15adceeae01fe1b10f8d3202a66d4676915',1,'MatrixFree']]],
  ['greater_11',['greater',['../structFloatingPointComparator.html#a05aa3c9dd24997debb7f4faae530ad23a7b8dc4fb0fb55fc8eb69ff080c45ed7e',1,'FloatingPointComparator']]],
  ['greater_5fthan_12',['greater_than',['../vectorization_8h.html#a31b02447b71a04a1ec9bdd1358751e45af9001e5685fe6f7cb467dc66269470b2',1,'vectorization.h']]],
  ['greater_5fthan_5for_5fequal_13',['greater_than_or_equal',['../vectorization_8h.html#a31b02447b71a04a1ec9bdd1358751e45ae69e99a9a1111b6a811f8e5bd832454f',1,'vectorization.h']]],
  ['grid_5frefinement_14',['grid_refinement',['../classTimeStepBase__Tria.html#a04c6f0ed3688c4e2424348d5b8b0dec6a97d0baaad98a47944648d1df2986ce96',1,'TimeStepBase_Tria']]],
  ['grid_5ftools_5fcompute_5flocal_5fto_5fglobal_5fvertex_5findex_5fmap_15',['grid_tools_compute_local_to_global_vertex_index_map',['../namespaceUtilities_1_1MPI_1_1internal_1_1Tags.html#a1c190e50dabbd9b60e230b843c6caa44aae63bc4062293f28fad1652db8ebe2da',1,'Utilities::MPI::internal::Tags']]],
  ['grid_5ftools_5fcompute_5flocal_5fto_5fglobal_5fvertex_5findex_5fmap2_16',['grid_tools_compute_local_to_global_vertex_index_map2',['../namespaceUtilities_1_1MPI_1_1internal_1_1Tags.html#a1c190e50dabbd9b60e230b843c6caa44a378386a9f53a28eac3a4a18310ecbd25',1,'Utilities::MPI::internal::Tags']]],
  ['group_17',['group',['../namespaceinternal.html#aa1c66592673b9ca3c1f4adecdc7897ceadb0f6f37ebeb6ea09489124345af2a45',1,'internal']]]
];

==> dealii-9.7.0-offline_documentation.tar.gz: doc/doxygen/deal.II/search/enumvalues_6.js <==
var searchData=
[
  ['gauss_5fjordan_0',['gauss_jordan',['../classPreconditionBlockBase.html#a0eb89cc35edc5ec8ef14baed1bbe9c66a57018c50701d00bdd089ed6c504f7cec',1,'PreconditionBlockBase']]],
  ['gaussianelimination_1',['GaussianElimination',['../structPETScWrappers_1_1PreconditionBoomerAMG_1_1AdditionalData.html#a5d92688a1fdd10088cddaf971b84e987ad29a355c6863a9d059169ef1fe131dcb',1,'PETScWrappers::PreconditionBoomerAMG::AdditionalData']]],
  ['general_2',['general',['../namespaceLAPACKSupport.html#a45557450a3c1ae0e74d7ddf12c43bc98af25b68380698c53fa6da3e05379c0855',1,'LAPACKSupport::general'],['../group__matrixfree.html#ggae024b29b6819e727d47016c6b6b53d8caec90e87a9874dab5ed93ed8793c58278',1,'internal::MatrixFreeFunctions::general']]],
  ['ghosted_3',['ghosted',['../structinternal_1_1MatrixFreeFunctions_1_1FaceSetup.html#aa8e29ddb5aafdd94db26be53c217f2eea4f7b10490f32a913036c1a09e14cc65e',1,'internal::MatrixFreeFunctions::FaceSetup']]],
  ['gmres_4',['gmres',['../classTrilinosWrappers_1_1SolverBase.html#afdefddba07cdfc566bfb749bcb5b0840aeb4057f8f19a15c916b61eaba68d5835',1,'TrilinosWrappers::SolverBase']]],
  ['gmv_5',['gmv',['../namespaceDataOutBase.html#aa3cbced9f1d4ae661f13018f4c980aa1a958eea3b2724c76d1c1ff20d69f7da4e',1,'DataOutBase']]],
  ['gnuplot_6',['gnuplot',['../classGridOut.html#af24aadcd00f93b7f428f44ecd40c44d9a9becaeaa34ee67f9686fef40075176e6',1,'GridOut::gnuplot'],['../namespaceDataOutBase.html#aa3cbced9f1d4ae661f13018f4c980aa1a025233c1a8124e5521952c7c7cd78df1',1,'DataOutBase::gnuplot']]],
  ['go_5fto_5fone_7',['go_to_one',['../namespaceMGTransferGlobalCoarseningTools.html#a0b3ae7f7ace3aef7bdcbca73ae07c126a4700af23eb58d665b1bffa9b2d8bd01a',1,'MGTransferGlobalCoarseningTools']]],
  ['gradient_8',['gradient',['../namespaceinternal.html#aa5bef221c94bc6b9c5441c306a72cdbaae2b6dfb8a5c48206992d8310d176c37c',1,'internal']]],
  ['gradients_9',['gradients',['../classMatrixFree.html#a751b5f06534d52773eba384d2c866a15ac2af294b46c59f4ca21a4aac2b2d97b1',1,'MatrixFree::gradients'],['../namespaceEvaluationFlags.html#a9b7c6d689cb76386839d0d13640f59aea91b5f00e4be473005cc331b8644ab2f1',1,'EvaluationFlags::gradients']]],
  ['gradients_5fall_5ffaces_10',['gradients_all_faces',['../classMatrixFree.html#a751b5f06534d52773eba384d2c866a15adceeae01fe1b10f8d3202a66d4676915',1,'MatrixFree']]],
  ['greater_11',['greater',['../structFloatingPointComparator.html#a05aa3c9dd24997debb7f4faae530ad23a7b8dc4fb0fb55fc8eb69ff080c45ed7e',1,'FloatingPointComparator']]],
  ['greater_5fthan_12',['greater_than',['../vectorization_8h.html#a31b02447b71a04a1ec9bdd1358751e45af9001e5685fe6f7cb467dc66269470b2',1,'vectorization.h']]],
  ['greater_5fthan_5for_5fequal_13',['greater_than_or_equal',['../vectorization_8h.html#a31b02447b71a04a1ec9bdd1358751e45ae69e99a9a1111b6a811f8e5bd832454f',1,'vectorization.h']]],
  ['grid_5frefinement_14',['grid_refinement',['../classTimeStepBase__Tria.html#a04c6f0ed3688c4e2424348d5b8b0dec6a97d0baaad98a47944648d1df2986ce96',1,'TimeStepBase_Tria']]],
  ['grid_5ftools_5fcompute_5flocal_5fto_5fglobal_5fvertex_5findex_5fmap_15',['grid_tools_compute_local_to_global_vertex_index_map',['../namespaceUtilities_1_1MPI_1_1internal_1_1Tags.html#a1c190e50dabbd9b60e230b843c6caa44aae63bc4062293f28fad1652db8ebe2da',1,'Utilities::MPI::internal::Tags']]],
  ['grid_5ftools_5fcompute_5flocal_5fto_5fglobal_5fvertex_5findex_5fmap2_16',['grid_tools_compute_local_to_global_vertex_index_map2',['../namespaceUtilities_1_1MPI_1_1internal_1_1Tags.html#a1c190e50dabbd9b60e230b843c6caa44a378386a9f53a28eac3a4a18310ecbd25',1,'Utilities::MPI::internal::Tags']]],
  ['group_17',['group',['../namespaceinternal.html#aa1c66592673b9ca3c1f4adecdc7897ceadb0f6f37ebeb6ea09489124345af2a45',1,'internal']]]
];
